#ifndef _SETTINGS_GUI_H
#define _SETTINGS_GUI_H

gboolean settings_dialog(void);
gboolean settings_dialog_gps(Gps *gps);
gboolean settings_dialog_osm(void);
gboolean settings_dialog_hardkeys(void);
gboolean settings_dialog_colors(void);
void update_gcs(void);

#endif
